.. certbot-dns-dnsmadeeasy documentation master file, created by
   sphinx-quickstart on Wed May 10 18:39:34 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to certbot-dns-dnsmadeeasy's documentation!
===================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: certbot_dns_dnsmadeeasy
   :members:

.. toctree::
   :maxdepth: 1

   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
